You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2011/02/28 17:17:30 UTC

svn commit: r1075404 - /commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java

Author: ggregory
Date: Mon Feb 28 16:17:29 2011
New Revision: 1075404

URL: http://svn.apache.org/viewvc?rev=1075404&view=rev
Log:
Better parameter name.

Modified:
    commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java

Modified: commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java?rev=1075404&r1=1075403&r2=1075404&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java (original)
+++ commons/proper/codec/trunk/src/java/org/apache/commons/codec/Decoder.java Mon Feb 28 16:17:29 2011
@@ -40,7 +40,7 @@ public interface Decoder {
      * implementation.  If a {@link ClassCastException} occurs
      * this decode method will throw a DecoderException.
      * 
      * @param pObject an object to "decode"
      * 
      * @return a 'decoded" object
      * 
@@ -50,6 +50,6 @@ public interface Decoder {
      * method is null, a param cannot be cast to the
      * appropriate type for a specific encoder.
      */
-    Object decode(Object pObject) throws DecoderException;
+    Object decode(Object source) throws DecoderException;
 }
@@ -40,7 +40,7 @@ public interface Decoder {
      * this decode method will throw a DecoderException.
      * 
-     * @param pObject an object to "decode"
+     * @param source the object to decode
      * 
      * @return a 'decoded" object